Monty Python's Flying Circus: Just the Words - Episode 41

# Episode Forty-one: Michael Ellis

Department store
Buying an ant
At home with the ant and other pets
Documentary on ants
Ant communication
Complaining about ant
Poetry reading (ants)
Toupee
Complaints office
Different endings

Colour code: Michael Palin - Eric Idle - Graham Chapman - Terry Jones - Terry Gilliam - Carol Cleveland

| Animated titles.
| CAPTION: 'THE END'
| Roll credits. Establishing shot of large Harrods-type store. Outside limousines and taxis are disgorging very rich customers. Small doormen in enormously large coats opening door of cars. A man with his nose bandaged comes out of the store. One large car pulls softly up to the curb, and as small doorman (Michael) opens its door, an enormously opulent lady (Terry J) in furs gets out. The doorman holds the door open. She knees him in the groin and walks on into the store. Chris Quinn (Eric) arrives on a bicycle. He parks the bicycle against the curb (the doorman flings it into the road) and goes into the outer hall of the store. He passes a couple leaving who also have noses bandaged. A gaggle of customers, mostly pepperpots, rush out. A very eager pepperpot lady shopper, going the other way, rushes between the two and bangs into a set of glass doors which have closed behind the gaggle. She cries out with pain clutching her nose and is escorted away by a large, coated attendant. Chris Quinn looks up at the list on the wall. It reads:
| BASEMENT: DANGEROUS GASES, VIRUSES, CONTAGIOUS DISEASES, RESTAURANT AND TOILET FIXINGS. GROUND FLOOR: MENSWEAR, BOYSWEAR, EFFEMINATE GOODS HALL, ILL HEALTH FOODS. MEZZANINE: TABLEWARE, KITCHEN GOODS, SOFT FURNISHINGS, HARD FURNISHINGS, ROCK-HARD FURNISHINGS. FIRST FLOOR: COMPLAINTS. SECOND FLOOR: COSMETICS, JEWELLERY, ELECTRICAL, SATIRE. THIRD FLOOR: NASAL INJURIES HALL, OTHER THINGS. FOURTH FLOOR: GRANITE HALL - ROCKS, SHALES, ALLUVIAL DEPOSITS, FELSPAR, CARPATHIANS, ANDES, URALS, MINING REQUISITES, ATOM-SPLITTING SERVICE. FIFTH FLOOR: COMPLAINTS. SIXTH FLOOR: COMPLAINTS. SEVENTH FLOOR: LEATHER GOODS. EIGHTH FLOOR: ROOF GARDEN. NINTH FLOOR: TELEVISION AERIALS. TENTH FLOOR: FRESH AIR, CLOUDS, OCCASIONAL PERIODS OF SUNSHINE.
| Quinn, knowing that there are doors, goes forward more cautiously and enters. The banging of noses on glass doors is a constant background theme. Cut to the gift department. A large lady is standing by counter holding a large cylinder with a rose attachment.
Lady | Yes this looks the sort of thing. May I just try it?
Assistant | Certainly, madam.
| The lady presses button and a sheet of flame shoots out across the hall.
Lady | Oh! Sorry! So sorry! (she is happy though) Yes that's fine.
Assistant | Is that on account, madam?
Lady | Yes.
| Chris walks by, watching with interest but not much concern, passing a customer whose back is on fire but who has not noticed. He approaches a counter with a sign saying 'Ant Counter'. He stands by the apparently empty counter for one moment, then rings a bell.
Chris | Hello? Hello?
| A strange rubber-masked head appears from below the other side of the counter and gesticulates at him making a strange noise. This soon stops.
First Assistant | Oh, I'm terribly sorry... (he takes off the mask to reveal a straight forward assistant) I thought you were someone else.
Chris | Oh I see, yes.
First Assistant | I'm sorry sir, can I help you?
Chris | Yes, yes, as a matter of fact you can, actually I was interested in the possibility... of purchasing one of your ... can I ask who you thought I was?
First Assistant | What?
Chris | Who did you think I was... just then... when you thought I was somebody.
First Assistant | Oh, it's no one you'd know, sir.
Chris | Well I might know them.
First Assistant | It's possible, obviously, but I think it's really unlikely.
Chris | Well, I know quite a lot...
First Assistant | I mean he's hardly likely to move in your circles, sir...
Chris | Why, is he very rich?
First Assistant | Oh, no, I didn't mean that, sir.
Chris | Is he a lord or something?
First Assistant | Oh, no, not at all.
Chris | Well look, this is very easy to settle. What is his name?.
First Assistant | What?
Chris | What is his name?
First Assistant | Well... er...
Chris | Yes?
First Assistant | Michael Ellis.
Chris | Who?
First Assistant | Michael Ellis.
Chris | I see.
First Assistant | Do you know him, sir?
Chris | Er ... Michael Ellis. Michael Ellis...
First Assistant | You don't
Chris | Well, I don't remember the name.
First Assistant | I think you would remember him, sir.
Chris | Why do you say that?
First Assistant | Well, would you remember a man six foot nine inches high, fortyish, and he's got a long scar from here to here and absolutely no nose?
Chris | ... oh, I think I do remember somebody like that...
First Assistant | Well, that's not Michael Ellis.
Chris | What?
First Assistant | He's a small man about this high with a high-pitched voice.
Chris | Right, I'm not going to buy an ant from you now.
First Assistant | (distressed) Oh, no, please.
Chris | No. You've not been properly trained. I demand another assistant.
First Assistant | Oh, no, come on... please...
Chris | No, I want another assistant.
First Assistant | All right! I'll get another assistant. (he disappears behind a curtain)
Chris | Thank you.
| The same assistant reappears with a long mandarin-style Chinese moustache.
First Assistant | (high-pitched voice) Hello sir, can I help you, sir?
Chris | No, I want a different assistant.
First Assistant | I am sir, I'm Mr Abanazar, sir.
Chris | Don't be silly.
First Assistant | (normal voice) Oh no, please please please let me help you...
Chris | No! I want another assistant.
First Assistant | Oh, no, come on, please...
Chris | If you don't give me another assistant...
First Assistant | No, no, I'll be very good, sir, really. (he becomes exaggeratedly polite) Good morning, sir... how are you, sir... bit parky outside today... isn't it, sir... ? A very nice suit you've got there, sir... you had a very close shave this morning, sir...
Chris | Right I'm going!
First Assistant | No, no, please... (he takes off his moustache) I'll get another assistant... (he rings the bell on the counter.)
| After a pause, very slowly indeed an identical mask to the first appears over the top of the counter right next to the first assistant, making the same noise very quietly. The first assistant sees him, starts and nudges him hard.
Second Assistant | Woooooo ....ooooooo...
First Assistant | It's not him!
| The second assistant makes a disappointed noise and disappears below.
Chris | (pointing over the counter at the disappeared assistant) I don't want him!
First Assistant | Oh please, give him a chance!
Chris | No!
Second Assistant | (appearing from below counter without a mask, looking immaculate) Yes, sir, can I be of any assistance?
Chris | Oh no, come on, don't try that!
Second Assistant | I'm sorry, sir... try what?
Chris | You know perfectly well what I mean.
Second Assistant | I'm afraid I don't, sir.
Chris | You were down behind there with a silly mask on going wooo-ooo...
Second Assistant | I don't think I was, sir.
Chris | All right, get the manager.
Second Assistant | There seems to have been some sort of misunderstanding, sir.
Chris | Manager!
First Assistant | This is the manager, sir.
Chris | What?
Second Assistant | (in a silly voice) Yes, I'm the manager.
Chris | Manager! (he keeps calling)
Second Assistant | It's a smashing store this, I can't recommend it too highly, well-lit, rat-free. It's a joy to manage. Oh yes, the freshest haddock in London, second floor, third floor Ribena, ants here, television and flame throwers over there, behind them our dinner-wagon exhibition closes at six...
First Assistant | (nudging him) Quick!
| They both disappear under the counter. The real manager arrives and presents himself to Chris.
Real Manager | Yes, sir? Can I help you, sir?
Chris | (noticing the 'manager' badge on his lapel) Yes, I want to complain about the assistants on this counter.
Real Manager | I'm sorry to hear that, sir, which ones?
Chris | Well, they're hiding now.
Real Manager | Sir?
Chris | They're hiding, down there behind the counter.
Real Manager | I see, sir. (he goes round counter, looks, but obviously can't see them; Chris goes round to join in the search)... well... there's nobody down here, sir.
Chris | They must have crawled through here, and made their escape through 'Soft Toys'. (he points)
Real Manager | Yes, of course.
Chris | They were wearing masks and making silly noises and one of them pretended to be the manager. He spoke like this.. (he does an impression)
Real Manager | Ah! I think I've got it, sir, I think I've got it! It's rag week.
Chris | Ragweek?
Real Manager | Yes, you know, for charity, sir.
Chris | Oh! I see. Some local college or university?
Real Manager | No, no it's the store's rag week.
Chris | The store's rag week?
Real Manager | Yes. The senior staff don't join in much - it's for the trainees really...
Chris | It's not very good for business is it?
Real Manager | Oh, It's for charity, sir. People are awfully good about it, you know. (he rattles a collecting tin)
Chris | Yes, yes, of course. (he puts a coin in)
Real Manager | Right, sir, I'll get you a senior assistant - ants, was it?
Chris | Yes, please.
Real Manager | (calling) Mr Snetterton? (Mr Snetterton approaches immediately; he is clearly the first assistant with very bad short crew-cut wig on) Could you look after this gentleman, Mr Snetterton?
Chris | I don't want him!
First Assistant | Oh please! Give me a chance!
Chris | No!
Real Manager | All right - Mr Hartford!
Hartford | Yes - good morning, sir - can I help you?
Chris | Yes, please, I'm interested in buying an ant.
Hartford | Ah yes - and what price were you thinking of paying, sir?
Chris | Oh, well, I hadn't actually got as far as that.
Hartford | Well sir, they start about half a p. but they can go as high as three p. or even three and a half p. for a champion - inflation I'm afraid...
Chris | Well, I should think one about one and a half p., please.
Hartford | Ah yes, well you should get a very serviceable little animal for that, sir. Quite frankly the half pence ones are a bit on the mangy side ... What length was sir thinking of?
Chris | Oh ... medium?
Hartford | Medium. Medium. Here we are, sir. (he tips some ants - which we can't see - out into a special ring on counter) That one there is an Ayrshire, and that one there is a King George bitch I think ... and that one killing the little flitbat is an Afghan.
Chris | That's a nice one.
Hartford | Let's see how you get on with him, eh? (he puts it on Chris's hand) Ah yes, he likes you. He's taken to you.
Chris | What do you feed them on?
Hartford | Blancmange.
Chris | Blancmange?
Hartford | I'm sorry. I don't know why I said that. No, you don't feed them at all.
Chris | Well, what do they live on?
Hartford | They don't. They die.
Chris | They die?
Hartford | Well of course they do, if you don't feed them.
Chris | I don't understand.
Hartford | You let them die, then you buy another one. It's much cheaper than feeding them and that way you have a constant variety of little companions.
Chris | Oh, I see.
Hartford | That's the advantage of owning an ant.
Chris | Right, well I'll take this one. Oh dear, I've dropped it...
Hartford | Never mind. Here's another one.
Chris | Is there anything else I'll need?
Hartford | Yes, sir - you'll need an ant house. (he produces a birdcage) This is the model we recommend, sir.
Chris | Won't it get out of there?
Hartford | Yes.
Chris | Well what's the point of having the cage?
Hartford | Well, none at all really. And then some pieces of cage furniture which will keep him entertained. (he produces microscopic things) Here's an ant-wheel, ant-swing, and a very nice one here, a little ladder - he can run up there and ring the bell at the top, that's a little trick he can learn.
Chris | Will he live long enough?
Hartford | Not really, no, but it's best to have one just in case, and here's a two-way radio he can play with... and of course you'll need the book. (he produces an expensive-looking book, thoughtlessly slams it down where the ants were, then hurriedly brushes them away)
Chris | The book?
Hartford | Yes, the book on ants.
Chris | (looking unsure) Yes...
Hartford | So, sir, that is, if I may say so, one hundred and eighty-four pounds one and a half p., sir.
Chris | Will you take a cheque?
Hartford | Yes, sir, if you don't mind leaving a blood-sample, and a piece of skin off the back of the scalp just here, sir ... (indicates a point behind his ear) sorry ... it's just for identification .-. you can't be too careful. (he hands him a little knife and some cotton wool)
Chris | Oh, well I think I'll put it on account.
Hartford | I should, sir... much less painful. Anyway sir, you know what they say about an ant. A friend for life, eh? Well, a friend for its life anyway... (Hartford loads the large cage, furniture, two-way radio and the book on ants into a huge box; with some difficulty he finds the ant; he picks it up carefully) His name is Marcus. (he drops him in the big box and pushes it across the counter; the box has on one side, in large letters 'live ant: handle with care'; it has breathing holes in it) If the little chap should go to an early grave, sir, give us a ring and we'll stick a few in an envelope, all right?
Chris | Thanks very much indeed.
Hartford | Not at all, thank you, Mr Ellis.
| Chris turns sharply. The first assistant comes quickly up to Hartford.
First Assistant | Sssssshh!
Chris | What did you say?
Hartford | I said thank you, Mr Ellis...
First Assistant | It's not him.
Hartford | Oh!
Chris | Why did you say I was Mr Ellis?
Hartford | (innocently) Who?
First Assistant | No, he didn't say that.
Chris | Yes he did. I heard him say 'Thank you, Mr Ellis'.
First Assistant | Oh, no, no - he said 'I'm jealous'.
Chris | What?
First Assistant | I'm jealous of your ant. Goodbye. Goodbye. (waves pointedly)
Chris | (leaving the counter) I don't care who Michael Ellis is!
| Chris passes a shop area labelled 'The Paisley Counter' where two customers are talking to mirrors in thick Irish accents. Chris moves on to lift. A little old lady passes, oblivious to the fact that her shopping trolley is smouldering. The lady passes and Chris is about to enter.
PA System | Will Mr Michael Ellis please go straight to the manager's office... I'll repeat that... (Chris wheels round and listens) Will Mr Nigel Mellish please go straight to the manager's office.
| Chris narrows his eyes suspiciously and gets into the lift cautiously. Cut to the kitchen in Chris Quinn's home. His mother is putting chopped meat into a line af at least half a dozen feeding bowls with various animal names on them. 'Babboon', 'Dromedary', 'Gorilla', 'Trout', and 'Pangolin'. There is a tiger in a cage in the middle of the kitchen, with a bowl marked 'Tiger' in front of him. A large cobra is hanging from the clothes drier and a wolf is in a cage below the sink. A monkey is on top of one of the cupboards. Chris enters with the box.
Mother | What have you got now?
Chris | I bought an ant, mother.
Mother | What d'you want one of them for! I'm not going to clean it out. You said you'd clean the tiger out, but do you? No, I suppose you've lost interest in it now. Now it'll be ant ant ant for a couple of days, then all of a sudden, 'oh, mum, I've bought a sloth' or some other odd-toed ungulate like a tapir.
Chris | It's really different this time, mum. I'm really going to look after this ant.
Mother | That's what you said about the sperm whale... now your papa's having to use it as a garage.
Chris | Well, you didn't feed it properly.
Mother | Where are we going to get forty-four tons of plankton from every morning? Your papa was dead vexed about that. They thought he was mad in the deli.
Chris | Well at least he's got a free garage. (growl from the tiger)
Mother | That's no good to him... his Hillman smells all fishy. (we hear a roar) Oh blimey, that's the tiger. He'll want his mandies.
Chris | Are you giving that tiger drugs?
Mother | 'Course I'm giving it drugs!
Chris | It's illegal.
Mother | You try telling that to the tiger.
Chris | I think it's dangerous.
Mother | Listen ... before he started fixing, he used to get through four Jehovah's witnesses a day. And he used to eat all of them, except the pamphlets.
Chris | Well he's not dim.
| A very loud roar and rattling of cage.
Mother | All right!
| She loads a syringe and starts to leave.
Chris | Well, I'm going to watch one of the televisions... come on Marcus.
| He puts Marcus in cage and is just about to take it through to the next room.
Mother | Michael's been on the phone all day for you.
Chris | Michael?
Mother | You know, Michael... Michael. Michael Ellis. He's been on the phone all day ... he came round twice.
Chris | What did he look like?
Mother | Oh, I didn't see him. The orange-rumped agouti answered the door. Only useful animal you ever bought, that.
Chris | Where is he now?
Mother | He's upstairs forging prescriptions for the sodding tiger!
Chris | No, no, where is Michael Ellis now?
Mother | Oh, I don't know... he said it wasn't important, anyway... all right, here I come.
| She goes to the tiger. Chris looks confused, then shrugs and goes into the sitting room with Marcus. In the room there are about twenty old televisions on shelves. Chris selects one of the televisions, puts it on the table, switches it on and settles down to watch it with Marcus. CAPTION (on the TV): 'UNIVERSITY OF THE AIR'
Announcer | (on the TV) Hello and welcome to the University of the Air. And first this afternoon, part seventeen in our series of lectures on animal communications. This afternoon we look at recent discoveries in the field of intraspecific signalling codes in the family formicidea.
Chris | That's a stroke of luck, Marcus...
| Cut to a restaurant. A waiter (Graham) stands at one side. Our hero (Terry J) enters, the waiter approaches him and they go through an elaborate signalling or greeting ceremony, stamping and so forth. The waiter does strange series of movements.
| CAPTION: 'MAY I HAVE YOUR COAT'
| Hero stamps a lot and clasps the waiters bottom.
| CAPTION: 'I DON'T HAVE A COAT. I AM AN ANT'
| Waiter routine.
| CAPTION: 'AREN'T WE ALL?'
| Hero routine.
| CAPTION: 'WHERE'S BRUNO?'
| Waiter routine.
| CAPTION: 'HE GOT TRODDEN ON'
| Hero routine.
| CAPTION: 'WHAT'S THE SPECIAL TODAY?'
| Waiter routine.
| CAPTION: 'FILLET OF ANTEATER'
| Hero routine.
| CAPTION: 'THAT'LL LEARN IT'
| Mother enters. She is rather torn and tattered and her face is bloodstained.
Mother | Turn that bloody thing off!
Announcer | We interrupt this programme to bring you the latest news of the extraordinary Michael Ellis saga. Apparently Michael Ellis... (mother switches it off)
Chris | Hey! I was watching that...
Mother | Bloody thing. It's upsetting the tiger. (there is a roar and a crash of breaking crockery from the kitchen) Oh Christ!
| She dashes across to the door and goes into the kitchen. Chris quickly switches the TV on.
Announcer | (waits for noises to stop) ... nd of the announcement. And now back to 'University of the Air', and our series for advanced medical students, 'Elements of Surgical Homeopathic Practice'. Part 68 - 'Ants'.
Chris | Ah! We're in luck again, Marcus.
| A surgeon appears on television. He makes a few ant gestures.
Surgeon | Hello formicidophiles! Before the blood and guts that you're waiting to see, let's have a look at the anatomy of the little ant.
| Cut to a drawing of an ant.
Ant Expert's Voice | The body of the ant is divided into three sections. (arrow indicates) The head, the thorax and the abdomen. They are enclosed in a hard amour-like covering called the exoskeleton, which provides some protection from other nasty little insects but unfortunately not from the dissector's scalpel. (an animated hand with a knife slices bits off the ant) See, nothing to it, he's not such a toughy. And his legs ... they help him carry hundreds of times his own weight, but look at this ... (a hand pulls the legs off) you're not so strong compared with me, four, five, six ... Ha!
Chris | I didn't know ants had six legs, Marcus!
Ant Expert | Well I can assure you they do, Mr Ellis.
Chris | Hey! You've got two legs missing! And that's a false feeler Marcus! Blimey!
| He leaps up, switches the TV off and hurls it into the corner onto a pile of used TVs, and hurries out. The tiger is quiet now. Mother, bloody and torn, is emptying a tin of 'Kit-E-Cobra' into a box marked 'Cobra'.
Chris | I'm taking this ant back, mother - he's got two legs missing.
Mother | Hey! Mrs McWong's been on the phone! The polar bear's been in her garden again.
Chris | Well I'll get it on the way back from the store.
Mother | Well mind you do - his droppings are enormous. (Chris goes through the door, mother shouts after him) Oh, and by the way, while you're out get us another couple of tellies would you, here's 180 quid. (she tosses a wad out to him)
| Cut to the garden outside. There are TVs heaped in the garden path. Chris catches the wad of notes and leaves through the garden gate as a TV van is unloading half a dozen TVs onto a trolley, prior to wheeling them into the house. Cut back to the store. Inside the lift. Chris stands there with his ant in his hand. There are also two ladies in Geman national costume. The lift lady, who has a wall-eye, a wooden leg, a tooth-brace, a hearing aid, a hilt-up shoe, a neck-brace, and a hook is reciting.
Lift Woman | Second floor ... stationery, leather goods, tribal head injuries, cricket bats, film stars, dolphinariums.
| The lift stops with some difficulty. The German girls get out with their baggage. In gets a man in Greek national costume holding an oar.
Lift Woman | Third floor ... cosmetics, books, Irish massage, tribal head-gear, ants.. (Chris starts to get out) but not complaints about ants!
Chris | Oh, where do I go to complain?
Lift Woman | Straight on, then left, then right past the thing, then, up the little stairs, then right by where it's gone all soft, then down the wobbly bit, left past the nail, past the brown stain on the wall to your right and it's the door marked exit straight ahead of you on the left.
Chris | Thank you.
Lift Woman | (the doors shut but we can just hear her voice) Fourth floor... kiddies' vasectomies...
| The ant counter. It is obviously the same place with a roughly made sign 'Complaints'. Chris is standing there with the original Assistant, who now has a plate in his lip and an enormous false chin about eight inches long and six inches across.
Chris | I don't want you.
First Assistant | (speaking with difficulty) Oh, something wrong with your little ant friend?
Chris | No! I'm not going to tell you.
First Assistant | Something missing in the leg department?
| The Manager appears.
Manager | Can I help you, sir?
| Chris looks down and sees that the Manager is half in a sack.
Chris | No! No! No! No!
Manager | Oh, it's all right, sir, it's for the sack race later on.
Chris | No, no, no, I want to speak to the General Manager, I want to complain.
Manager | Oh, well you want the Toupee Hall in that case, sir.
Chris | The what?
Manager | The Toupee Hall, Mr Ellis. (he hops off)
| Chris approaches a stocking counter where lady assistant is serving two heavies who are trying on nylons over their heads. Chris speaks to the assistant.
Chris | (embarrassed) Excuse me - could you tell me the way to the Toupee Hall, please?
Assistant | Sorry?
Chris | The Toupee Hall.
Assistant | The what?
Chris | The Toupee Hall.
Assistant | Oh, the Toupee Hall (loudly) Gladys, where are toupees now?
Gladys | Toupees? (people start to look)
Assistant | This gentleman wants one.
Gladys | (even louder) A toupee?
Chris | Well, no, actually...
Gladys | I think they're in surgical appliances now.
Assistant | That's right, yes, you go left at artificial limbs and hearing aids, right at dentures and it's on your left just by glass eyes. It doesn't say toupees to avoid embarrassing people, but you can smell 'em.
| People by this time have formed a ring round to see who it is.
Chris | Thank you.
| As he moves off people peer at his head.
Woman | (to friend) You can see the join.
| Chris in order to avoid this embarrassment, dives into the nearest department. A sign over the door reads 'Victorian poetry reading hall'. Cut to a poetry reading. Wordsworth, Shelley, Keats and Tennyson are present. Chris stands quietly in the comer hoping not to be noticed.
Old Lady | Good afternoon, ladies and gentlemen, it's so nice to see such a large turnout this afternoon. And I'd like to start off by welcoming our guest speakers for this afternoon, Mr Wadsworth...
Wordsworth | Wordsworth!
Old Lady | Sorry, Wordsworth... Mr John Koots, and Percy Bysshe.
Shelley | Shelley!
Old Lady | Just a little one, medium dry, (a dwarf assistant pours her a sherry) and Alfred Lorde.
Tennyson | Tennyson.
Old Lady | Tennis ball.
Tennyson | Son, son.
Old Lady | Sorry - Alfred Lord, who is evidently Lord Tennisball's son. And to start off I'm going to ask Mr Wadsworth to recite his latest offering, a little pram entitled 'I wandered lonely as a crab' and it's all about ants.
| Murmur of exalted anticipation. Wordsworth rises rather gloomily.
Wordsworth | I wandered lonely as a cloud That floats on high over vales and hills When all at once I saw a crowd A host of golden worker ants.
| Ripples of applause.
Old Lady | Thank you, thank you, Mr Bradlaugh. Now, Mr Bysshe.
Shelley | Shelley.
Old Lady | Oh... (the dwarf refills her glass)... is going to read one of his latest psalms, entitled 'Ode to a crab'.
Shelley | (rising: and taking his place quietly) Well, it's not about crabs actually, it's called 'Ozymandias'. It's not an ode. I met a traveller in an antique land Who said 'Six vast and trunkless legs of stone Stand in the desert And on the pedestal these words appear My name is Ozymandias, King of Ants (oohs from his audience) Look on my feelers, termites, and despair I am the biggest ant you'll ever see The ants of old weren't half as bold and big And fierce as me'.
| Enormous applause.
Old Lady | Thank you Mr Amontillado. I'd like to ask one or two of you at the back not to soil the carpet, there is a restroom upstairs if you find the poems too exciting (she falls over) Good afternoon, next, Mr Dennis Keat will recite his latest problem 'Ode to a glass of sherry'. (she falls off the podium)
Keats | My heart aches and a drowsy numbness pains My senses, as though an anteater I'd seen (panic spreads and the audience half rise) A nasty long-nosed brute (screams from the audience) With furry legs and sticky darting tongue I seem to feel its cruel jaws Crunch crunch there go my legs Snap snap my thorax too (various screaming women faint) My head's in a twain, there goes my brain Swallow, swallow, swallow, slurp (he loses control)
Old Lady | Mr Keats, Mr Keats, please leave immediately.
Keats | It's true. Don't you see. It's true. It happens.
Old Lady | (she bustles him out) Ladies and gentlemen, I do apologize for that last... well I hesitate to call it a pram ... but I had no idea ... and talking of filth... I have asked you once about the carpet ... Now, I do appreciate that last poem was very frightening... but please! Now before we move on to tea and pramwiches, I would like to ask Arthur Lord Tenniscourt to give us his latest little plum entitled 'The Charge of the Ant Brigade'.
Tennyson | Half an inch, half an inch...
| Enter Queen Victoria with a fanfare, followed by Albert's coffin.
All | The Queen, the Queen. (they all bow and scrape)
Queen Victoria | My loyal subjects, we are here today on a matter of national import. My late husband and we are increasingly disturbed by recent developments in literary style (developing a German accent) that have taken place here in Germany ... er England. There seems to be an increasing tendency for ze ent... the ent... the ant... to become the dominant ... was is der deutsches Entwicklungsbund...
Attendant | Theme.
Queen Victoria | Theme ... of modern poetry here in Germany. We are not ... amusiert? (an attendant whispers) Entertained. From now on, ants is verboten. Instead it's skylarks, daffodils, nightingales, light brigades and ... was ist das schreckliche Gepong ... es schmecke wie ein Scheisshaus... und so weiter. Well, we must away now or we shall be late for the races. God bless you alles.
| Chris leaves. We cut to him outside a door with a sign saying 'Electric Kettles'.
Voice | Psst! Electric kettles over here, Sir.
| A hand holding a sign saying 'Toupees' beckons him. He goes over to door and is ushered through. There are pictures of famous bald world figures with toupees on the walls.
Toupee Manager | Don't worry, sir, you're among friends now, sir. (the manager has an appalling toupee; Chris sees it and tries not to stare; the manager introduces his assistants) Mr Bradford, Mr Crawley. (Bradford and Crawley come forward; each has a toupee worse than the others) These are our fitters, sir. We've had a lot of experience in this field and we do pride ourselves we offer the best and most discreet service available. I don't know whether you'll believe this sir, but one of us is actually wearing a toupee at this moment...
Chris | Well, you all are, aren't you?
| They rush to a mirror.
Bradford | Have you got one?
Crawley | Yes, but I didn't know...
Toupee Manager | I didn't realize that you two... I thought it was me,
Crawley | Yes, I thought it was me.
Bradford | So did I. (to Crawley) That is good.
Chris | Actually, I only came in here to ask where the manager's office was.
Toupee Manager | Just a minute - someone told you we all had toupees?
Chris | No.
Crawley | Oh yeah?
Bradford | How did you know?
Chris | Well ... it's pretty obvious, isn't it?
Crawley | What do you mean obvious! His is undetectable.
Chris | Well, it's a different colour, for a start.
Bradford | Is it?
Crawley | Course it isn't!
Chris | And it doesn't fit in with the rest of his hair... it sort of sticks up in the middle.
Bradford | It's better than yours.
Crawley | Yes.
Chris | I'm not wearing one. (they all jeer)
Toupee Manager | Oh, I see, you haven't got one.
Crawley | Why did you come in here then?
Chris | They told me to find the manager's office here.
| They all jeer again.
Bradford | Oh no, not again.
Crawley | That's a bit lame, isn't it...
Chris | It's the truth!
All | Manager's office. (they laugh mockingly)
Bradford | Yeah, look at it. Where did you get that, Mac Fisheries?
Toupee Manager | Dreadful, isn't it?
Crawley | Nylon?
Chris | It's not, it's real look. (he pulls it)
All | Oh yeah, anyone can do that.
| They all do the same. Bradford incautiously pulls his loose.
Crawley | Come on, get if off.
Chris | Get away.
Toupee Manager | Look, do you want a proper one?
Chris | No, I don't need one.
Bradford | There's no need to be ashamed.
Crawley | We've all owned up.
Chris | I'm not wearing one.
| They all look at each other for a moment, registering 'a hard case'.
Toupee Manager | Don't you see... this is something you've got to come to terms with.
Chris | I am not wearing a toupee! They just told me to come in here to find the manager's office, to complain about my ant!
| They look at each other.
Crawley | Pathetic, isn't it.
Bradford | Complain about an ant?
Toupee Manager | This is for your own good.
| He grabs Chris's hair. A fight ensues in which all the assistants get their toupees dislodged. Chris is backed up against a door marked: 'Strictly no admittance'. He suddenly ducks out through this door. Cut to the other side of the door. Chris turns and double takes. It is the manager's office. There is a long line of people sitting waiting to complain. The manager looks up.
Complaints Manager | (irritably) All right. Take a seat.
| Chris shuts the door and takes a seat at the end of a line often people waiting to complain: the German clothes prop man; the Icelandic honey week man; a Greek with a motor tyre; a man with a lawn mower with a cat sticking out of it; a man with a bandaged nose holding a dog with a bandaged nose; a lady with a bandaged nose; a lady with a bandaged nose and a pram with a small column of smoke rising from it; a rather butch lady with her head through a tennis racket; a man with a cigar in his mouth that has obviously exploded - his face is blackened and his collar awry; a man in a terrible suit with one arm twice as long as a normal sleeve and trousers that finish at mid-thigh. A uniformed shop attendant is sitting next to a rather well dressed lady in twin set and pearls, and her equally distinguished looking husband. The attendant is occasionally touching the lady's cheek and peering into her eyes. The lady and the husband stare straight ahead. Next to them is Colonel Ewing. At the desk is the lady with the flame thrower. Part of the manager's desk and the entire corner of the office are blackened and smoking.
Lady | You see! There ought to be a safety catch on it, I mean ... ohhhh! (a spurt of flame shoots out) I mean, what if this fell into the wrong hands?
Complaints Manager | Yes, madam. I'll speak to the makers personally, all right?
Lady | Would you? It would put my mind at ease.
| She leaves closing the door. We hear the flame thrower.
Lady's Voice | Sorry...
Complaints Manager | Next?
| The colonel gets up. As he does so Mr Zyndenky (the husband) indicates his wife and the attendant.
Mr Zyndersky | He's still molesting her.
Complaints Manager | Yes, yes, I'll see to you in a moment, sir. (the colonel sits at the manager's desk)
Colonel Ewing | I've got a complaint to make.
Complaints Manager | Do take a seat. I'm sorry it's on fire.
Colonel Ewing | Oh, not at all. (he sits on it) I got used to this out east.
Complaints Manager | Where were you out east?
Colonel Ewing | Oh, Norway ... Sweden ... places like that... oh I'm terribly sorry, my suit seems to keep catching fire.
Complaints Manager | Extinguisher?
Colonel Ewing | Oh no, thank you, I think we'd better let it run its course. I was just thinking... Norway is not very east, is it? I should have said when I was out north. (he slaps at the flames)
Complaints Manager | Are there many fires in Norway?
Colonel Ewing | Good Lord yes. The place is a constant blaze. Wooden buildings, d'you know. I lost my wife in Norway.
Complaints Manager | I am sorry to hear that.
Colonel Ewing | Why, did you know her?
Complaints Manager | No, I meant...
Colonel Ewing | Oh I see. No, she wasn't a favourite of mine. We were out strolling across a fiord one day when one of the local matadors came out of his tree house and flung a load of old scimitars and guillotines out that he'd got cluttering up his wine cellar and apparently rather a large proportion of them landed on my wife causing her to snuff it without much more ado.
Complaints Manager | Yes, yes - well look...
| Ding-dong of store PA. An announcer speaks.
Announcer | Here is an important announcement about Michael Ellis. (Chris looks up at loudspeaker; everyone turns towards it) It is now the end of 'Michael Ellis' week. From now on it is 'Chris Quinn' week. (murmur of excitment)
Chris | What a rotten ending.
| Cut to a polite, well dressed assistant at a counter with a big sign saying 'End of Show Department' behind him.
Assistant | Well it is one of our cheapest, sir.
Chris | What else have you got?
Assistant | Well, there's the long slow pull-out, sir, you know, the camera tracks back and back and mixes...
| As he speaks we pull out and mix through to the exterior of the store. Mix through to even wider zoom ending up in aerial view of London. It stops abruptly and we cut back to Chris.
Chris | No, have you got anything more exciting?
Assistant | How about a chase?
| The manager and the toupee assistants suddenly, appear at a door.
Manager | There he is!
| Exciting chase music. They pursue Chris out of the hall and into another part of the store. Then cut back to Chris at counter.
Chris | Oh, no, no, no.
Assistant | Walking into the sunset?
Chris | What's that one?
| Dramatic sunset shot on a beach. We can just see the back of Chris and the assistant as they walk together towards the setting sun. The assistant is gesturing and describing it.
Assistant | You know ... two lone figures silhouetted against the dying rays of the setting sun. The music swells, you've got a lump in your throat and a tear in your eye...
| Cut back to the store.
Chris | Oh no.
Assistant | Oh, pity, I rather like that one...
Chris | They're all a bit off the point, you see.
Assistant | Well there is one that ties up the whole Michael Ellis thing, but....
Chris | But what... ?
Assistant | Oh, no, nothing, nothing...
Chris | Look, who is this Michael Ellis?
Assistant | How about a happy ending, sir?
| A girl rushes up to Chris and flings her arms around him.
Girl | Oh Chris! Thank God you're safe.
Assistant | No, you wouldn't want that, would you.
| This time we see the girl has disappeared.
Chris | Why wouldn't I want that?
Assistant | What about summing up from the panel? That's cheap. You know - the big match experts.
| Panel in typical football panel set. Malcolm Allison, Brian Clough, and huge still of Jimmy Hill on set behind.
Malcolm Allison | Yes. It was quite a good show. I think that the Michael Ellis character was a little overdone.
Brian Clough | Well, I don't agree with that, Malcolm, quite frankly the only bit I liked was this bit with me in it now.
| Cut back to the store.
Assistant | No? Slow fade?
| The picture begins to fade.
Chris | Nnnn... no.
| The picture comes up again.
Assistant | Well, how about a sudden ending?
| Blackout.